<template>
  <Dropdown
    v-slot="{ close }"
    placement="bottom-end"
  >
    <RouterLink
      :to="{ name: 'links.analytics', params: { id: link.id } }"
      class="block w-full px-4 py-2 text-left text-sm text-gray-700 hover:bg-gray-100 hover:text-gray-900"
      @click="close"
    >
      {{ $t("app.links.dropdown.analytics") }}
    </RouterLink>
    <RouterLink
      :to="{ name: 'links.update', params: { id: link.id } }"
      class="block w-full px-4 py-2 text-left text-sm text-gray-700 hover:bg-gray-100 hover:text-gray-900"
      @click="close"
    >
      {{ $t("app.links.dropdown.update") }}
    </RouterLink>
    <button
      class="block w-full px-4 py-2 text-left text-sm text-gray-700 hover:bg-gray-100 hover:text-gray-900"
      type="button"
      @click="copyToClipboard(link.short_url)"
    >
      {{ $t("app.links.dropdown.clipboard") }}
    </button>
    <button
      class="block w-full px-4 py-2 text-left text-sm text-gray-700 hover:bg-gray-100 hover:text-gray-900"
      type="button"
      @click="copyToClipboard(link.qr)"
    >
      {{ $t("app.links.dropdown.qr") }}
    </button>
  </Dropdown>
</template>

<script lang="ts" setup>
import Dropdown from "@/js/contexts/shared/ui/components/floating/Dropdown.vue";
import type { Link } from "@/js/contexts/shared/models/Link";
import { useClipboard } from "@vueuse/core";
import useNotification from "@/js/contexts/shared/composables/useNotification";

defineProps<{
  link: Link;
}>();

const { t } = useI18n();
const { successNotification } = useNotification();

const copyToClipboard = (value: string) => {
  useClipboard()
    .copy(value)
    .then(() => successNotification(t("app.clipboard.copied")));
};
</script>
